// 搜索功能脚本
(function() {
    // 创建搜索功能
    // 创建搜索图标 - 调整位置和样式
    const searchIcon = document.createElement('div');
    searchIcon.innerHTML = '🔍';
    searchIcon.style.cssText = `
        position: fixed;
        right: 8px;
        bottom: 410px;  // 改为底部固定位置
        width: 44px;
        height: 44px;  // 稍微调小一点更适合移动端
        background: #ffffff;
        border-radius: 50%;
        display: flex;
        align-items: center;
        justify-content: center;
        cursor: pointer;
        font-size: 35px;
        box-shadow: 0 2px 12px rgba(0,0,0,0.15);
        z-index: 10001;
        transition: all 0.1s ease;
    `;

    // 创建搜索框容器 - 完全重构样式
    const searchContainer = document.createElement('div');
    searchContainer.style.cssText = `
        position: fixed;
        bottom: 0;          // 改为底部弹出式
        left: 0;
        width: 100%;
        background: #ffffff;
        padding: 16px;
        border-radius: 20px 20px 0 0;
        box-shadow: 0 -4px 16px rgba(0,0,0,0.1);
        z-index: 10000;
        display: none;
        flex-direction: column;
        gap: 16px;
        max-height: 85vh;   // 限制最大高度
        overflow-y: auto;
        transition: transform 0.3s ease;
        transform: translateY(100%);
    `;

    // 克隆现有的搜索表单并添加到搜索容器
    const existingSearchForm = document.getElementById('searchform');
    if (existingSearchForm) {
        const clonedForm = existingSearchForm.cloneNode(true);
        clonedForm.id = 'clonedSearchForm';
        searchContainer.appendChild(clonedForm);
    }

    // 点击图标显示/隐藏搜索框
    searchIcon.onclick = (e) => {
        e.stopPropagation();
        if (searchContainer.style.display === 'none') {
            searchContainer.style.display = 'flex';
            // 使用 requestAnimationFrame 确保 display 变更后再添加动画
            requestAnimationFrame(() => {
                searchContainer.style.transform = 'translateY(0)';
            });
        } else {
            searchContainer.style.transform = 'translateY(100%)';
            // 等待动画完成后隐藏
            setTimeout(() => {
                searchContainer.style.display = 'none';
            }, 300);
        }
    };

    // 点击外部区域隐藏搜索框
    document.addEventListener('click', function(e) {
        if (!searchContainer.contains(e.target) && e.target !== searchIcon) {
            searchContainer.style.display = 'none';
        }
    });

    // 处理搜索相关事件
    function hideSearchContainer() {
        searchContainer.style.transform = 'translateY(100%)';
        setTimeout(() => {
            searchContainer.style.display = 'none';
            // 重置搜索框的值为原始搜索框的值
            const clonedSearchInput = searchContainer.querySelector('#searchInput');
            const originalSearchInput = document.getElementById('searchInput');
            if (clonedSearchInput && originalSearchInput) {
                clonedSearchInput.value = originalSearchInput.value;
            }
        }, 300);
    }

    // 为克隆的搜索表单添加事件监听
    const clonedSearchButton = searchContainer.querySelector('#searchButton');
    if (clonedSearchButton) {
        clonedSearchButton.addEventListener('click', function(event) {
            event.preventDefault();
            const searchQuery = searchContainer.querySelector('#searchInput').value.trim();
            if (searchQuery === '') {
                alert('请输入搜索内容');
                return;
            }
            // 更新原始搜索框的值
            const originalSearchInput = document.getElementById('searchInput');
            if (originalSearchInput) {
                originalSearchInput.value = searchQuery;
                const originalSearchButton = document.getElementById('searchButton');
                if (originalSearchButton) {
                    originalSearchButton.click();
                }
            }
            hideSearchContainer();
        });
    }

    // 修改清空按钮功能
    function hideSearchContainer() {
        searchContainer.style.transform = 'translateY(100%)';
        setTimeout(() => {
            searchContainer.style.display = 'none';
            // 重置搜索框的值为原始搜索框的值
            const clonedSearchInput = searchContainer.querySelector('#searchInput');
            const originalSearchInput = document.getElementById('searchInput');
            if (clonedSearchInput && originalSearchInput) {
                clonedSearchInput.value = originalSearchInput.value;
            }
        }, 300);
    }

    // 为克隆的搜索表单添加清空功能
    const clonedClearButton = searchContainer.querySelector('button[onclick="clearInput(\'searchInput\')"]');
    if (clonedClearButton) {
        clonedClearButton.onclick = function() {
            const clonedSearchInput = searchContainer.querySelector('#searchInput');
            if (clonedSearchInput) {
                clonedSearchInput.value = '';
                clonedSearchInput.focus();
            }
            // 同步清空原始搜索框
            const originalSearchInput = document.getElementById('searchInput');
            if (originalSearchInput) {
                originalSearchInput.value = '';
            }
        };
    }

    // 修改汉字音搜索功能
    const clonedConvertButton = searchContainer.querySelector('#convertButton');
    if (clonedConvertButton) {
        clonedConvertButton.addEventListener('click', function(e) {
            e.preventDefault();
            const clonedSearchInput = searchContainer.querySelector('#searchInput');
            if (!clonedSearchInput || !clonedSearchInput.value.trim()) {
                alert('请输入需要搜索的文字');
                return;
            }

            try {
                const parts = clonedSearchInput.value.trim().split(/\s*\|\s*/);
                const cleanText = parts[0].trim();
                const typePrefix = cleanText.match(/^(audio:|zip:|doc:|exe:|pic:|video:|nopath:|nofileonly:)/);
                const textToConvert = typePrefix ? cleanText.replace(typePrefix[0], '') : cleanText;
                
                const pinyin = PinyinHelper.convertToPinyinString(textToConvert, '', PinyinFormat.WITHOUT_TONE);
                const newSearchText = `${typePrefix || ''}${textToConvert} | ${pinyin}`;
                
                clonedSearchInput.value = newSearchText;
                
                // 同步更新原始搜索框
                const originalSearchInput = document.getElementById('searchInput');
                if (originalSearchInput) {
                    originalSearchInput.value = newSearchText;
                    const originalSearchButton = document.getElementById('searchButton');
                    if (originalSearchButton) {
                        originalSearchButton.click();
                    }
                }
                hideSearchContainer();
            } catch (error) {
                console.error('转换错误:', error);
                alert('转换失败，请检查输入或刷新页面重试');
            }
        });
    }

    // 为所有过滤按钮添加正确的行为
    const filterButtons = searchContainer.querySelectorAll('.button-container button');
    filterButtons.forEach(button => {
        const filterType = button.getAttribute('data-filter');
        if (filterType) {
            button.onclick = function(e) {
                e.preventDefault();
                const clonedSearchInput = searchContainer.querySelector('#searchInput');
                if (clonedSearchInput) {
                    const currentSearch = clonedSearchInput.value.trim();
                    
                    if (!currentSearch) {
                        clonedSearchInput.value = filterType;
                    } else if (!currentSearch.startsWith(filterType)) {
                        const cleanSearch = currentSearch.replace(/^(audio:|zip:|doc:|exe:|pic:|video:|nopath:|nofileonly:|folder:)/, '');
                        clonedSearchInput.value = filterType + cleanSearch;
                    }
                    
                    // 同步更新原始搜索框并触发搜索
                    const originalSearchInput = document.getElementById('searchInput');
                    if (originalSearchInput) {
                        originalSearchInput.value = clonedSearchInput.value;
                        const originalSearchButton = document.getElementById('searchButton');
                        if (originalSearchButton) {
                            originalSearchButton.click();
                        }
                    }
                }
                hideSearchContainer();
            };
        }
    });

    // 添加到页面
    document.body.appendChild(searchIcon);
    document.body.appendChild(searchContainer);

    // 添加键盘弹出时的处理
    window.addEventListener('resize', () => {
        if (searchContainer.style.display !== 'none') {
            // 确保搜索框在键盘弹出时仍然可见
            window.scrollTo(0, 0);
            searchContainer.scrollIntoView({ behavior: 'smooth' });
        }
    });

    // 添加触摸事件处理（可选）
    let startY = 0;
    searchContainer.addEventListener('touchstart', (e) => {
        startY = e.touches[0].clientY;
    });

    searchContainer.addEventListener('touchmove', (e) => {
        const deltaY = e.touches[0].clientY - startY;
        if (deltaY > 50) { // 向下滑动超过50px时关闭
            hideSearchContainer();
        }
    });
})();
